@@ -1,7 +1,10 @@
 
-__ALL__ = ["Song", "Bass", "BassException", "BassChannel", "BassStream"]
+__all__ = ["Song", "Playlist", "Bass", "BassException", "BassChannel", "BassStream"]
 
 from .song import Song
+from .playlist import Playlist
 from .bass_module import Bass, BassException
 from .bass_channel import BassChannel
-from .bass_stream import BassStream
\ No newline at end of file
+from .bass_stream import BassStream
+
+__version__ = "0.0.2"
\ No newline at end of file
